﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using com.citizen.sdk.LabelPrint;

namespace Citizen_Label_sample_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            DataTable dataTable1 = new DataTable("ComboBox");
            dataTable1.Columns.Add("Display", typeof(string));
            dataTable1.Columns.Add("Value", typeof(int));
            dataTable1.Rows.Add("NET", LabelConst.CLS_PORT_NET);
            dataTable1.Rows.Add("Bluetooth", LabelConst.CLS_PORT_Bluetooth);
            dataTable1.Rows.Add("COM", LabelConst.CLS_PORT_COM);
            comboBox1.DataSource = dataTable1;
            comboBox1.DisplayMember = "Display";
            comboBox1.ValueMember = "Value";
            comboBox1.SelectedIndex = 0;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            // Create an instance( LabelPrinter class )
            LabelPrinter printer = new LabelPrinter();

            // Get Type
            int type = (int)comboBox1.SelectedValue;

            // Get Address
            String addr = textBox1.Text;

            // Set COMM Properties( COMM only )
            if (LabelConst.CLS_PORT_COM == type)
            {
                printer.SetCommProperties(LabelConst.CLS_COM_BAUDRATE_9600, LabelConst.CLS_COM_PARITY_NONE, LabelConst.CLS_COM_HANDSHAKE_DTRDSR);
            }

            // Connect printer
            int result = printer.Connect(type, addr);

            if (LabelConst.CLS_SUCCESS == result)
            {
                // Printer Check
                result = printer.PrinterCheck();

                // Disconnect
                printer.Disconnect();

                if (LabelConst.CLS_SUCCESS == result)
                {
                    String msg = "PrinterCheck() : Success\n";

                    // CommandInterpreterInAction
                    int status = printer.GetCommandInterpreterInAction();
                    msg += "\n CommandInterpreterInAction -> " + status;

                    // PaperError
                    status = printer.GetPaperError();
                    msg += "\n PaperError -> " + status;

                    // RibbonEnd
                    status = printer.GetRibbonEnd();
                    msg += "\n RibbonEnd -> " + status;

                    // BatchProcessing
                    status = printer.GetBatchProcessing();
                    msg += "\n BatchProcessing -> " + status;

                    // Printing
                    status = printer.GetPrinting();
                    msg += "\n Printing -> " + status;

                    // Pause
                    status = printer.GetPause();
                    msg += "\n Pause -> " + status;

                    // WaitingForPeeling
                    status = printer.GetWaitingForPeeling();
                    msg += "\n WaitingForPeeling -> " + status;

                    // Show Status
                    MessageBox.Show(msg);
                }
                else
                {
                    // Printer Check Error
                    MessageBox.Show("PrinterCheck Error : " + result.ToString());
                }
            }
            else
            {
                // Connect Error
                MessageBox.Show("Connect Error : " + result.ToString());
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            // Create an instance( LabelDesign class )
            LabelDesign design = new LabelDesign();

            // Text
            design.DrawTextPtrFont("Sample Print", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE_B, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_24, 20, 300);

            // QRCode
            design.DrawQRCode("DrawQRCode", LabelConst.CLS_ENC_CDPG_IBM850, LabelConst.CLS_RT_NORMAL, 4, LabelConst.CLS_QRCODE_EC_LEVEL_H, 20, 220);

            // Rect(fill)
            design.FillRect(20, 150, 350, 40, LabelConst.CLS_SHADED_PTN_11);

            // BarCode
            design.DrawBarCode("0123456789", LabelConst.CLS_BCS_CODE128, LabelConst.CLS_RT_NORMAL, 3, 3, 30, 20, 70, LabelConst.CLS_BCS_TEXT_SHOW);


            // Create an instance( LabelPrinter class )
            LabelPrinter printer = new LabelPrinter();

            // Get Type
            int type = (int)comboBox1.SelectedValue;

            // Get Address
            String addr = textBox1.Text;

            // Set COMM Properties( COMM only )
            if (LabelConst.CLS_PORT_COM == type)
            {
                printer.SetCommProperties(LabelConst.CLS_COM_BAUDRATE_9600, LabelConst.CLS_COM_PARITY_NONE, LabelConst.CLS_COM_HANDSHAKE_DTRDSR);
            }

            // Connect printer
            int result = printer.Connect(type, addr);
            if (LabelConst.CLS_SUCCESS == result)
            {
                // Get Properties
                int printDarkness = printer.GetPrintDarkness();
                if (LabelConst.CLS_PROPERTY_DEFAULT == printDarkness)
                {
                    // Set Properties
                    printer.SetPrintDarkness(10);
                }
                // Print Label
                result = printer.Print(design, 0001);

                // Disconnect
                printer.Disconnect();

                if (LabelConst.CLS_SUCCESS != result)
                {
                    // Print Error
                    MessageBox.Show("Print Error : " + result.ToString());
                }
            }
            else
            {
                // Connect Error
                MessageBox.Show("Connect Error : " + result.ToString());
            }
        }
    }
}