﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using com.citizen.sdk.LabelPrint;

namespace StatusChecking
{
    public partial class Form1 : Form
    {
        private LabelPrinter printer;
        private bool bExec;

        public Form1()
        {
            InitializeComponent();

            DataTable dataTable1 = new DataTable("ComboBox");
            dataTable1.Columns.Add("Display", typeof(string));
            dataTable1.Columns.Add("Value", typeof(int));
            dataTable1.Rows.Add("NET", LabelConst.CLS_PORT_NET);
            dataTable1.Rows.Add("Bluetooth", LabelConst.CLS_PORT_Bluetooth);
            dataTable1.Rows.Add("COM", LabelConst.CLS_PORT_COM);
            comboBox1.DataSource = dataTable1;
            comboBox1.DisplayMember = "Display";
            comboBox1.ValueMember = "Value";

            // Create an instance( LabelPrinter class )
            printer = new LabelPrinter();
        }

        /// <summary>
        /// "Start Checking Status" button pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void startBtn_Click(object sender, EventArgs e)
        {
            statusBox.Text = "";

            // Get Type
            int type = (int)comboBox1.SelectedValue;

            // Get Address
            String addr = textBox1.Text;

            // Set COMM Properties( COMM only )
            if (LabelConst.CLS_PORT_COM == type)
            {
                printer.SetCommProperties(LabelConst.CLS_COM_BAUDRATE_9600, LabelConst.CLS_COM_PARITY_NONE, LabelConst.CLS_COM_HANDSHAKE_DTRDSR);
            }

            // Connect printer
            int result = printer.Connect(type, addr);

            if (LabelConst.CLS_SUCCESS == result)
            {
                startBtn.Enabled = false;
                stopBtn.Enabled = true;
                bExec = false;

                timer1.Interval = 2000;
                timer1.Enabled = true;
            }
            else
            {
                // Connect Error
                MessageBox.Show("Connect Error : " + result.ToString());
            }
        }

        /// <summary>
        /// "Stop" button pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void stopBtn_Click(object sender, EventArgs e)
        {
            timer1.Enabled = false;
            startBtn.Enabled = true;
            stopBtn.Enabled = false;

            printer.Disconnect();
        }

        /// <summary>
        /// Checks the status and populates into each property
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer1_Tick(object sender, EventArgs e)
        {
            if (bExec) return;

            statusBox.Text = "";
            bExec = true;

            // Get status
            int ret = printer.PrinterCheck();

            bExec = false;

            if (ret == LabelConst.CLS_SUCCESS)
            {
                string msg = "";
                msg += printer.GetCommandInterpreterInAction().ToString() + ": Command interpreter in action" + "\r\n";
                msg += printer.GetPaperError().ToString() + ": Paper error" + "\r\n";
                msg += printer.GetRibbonEnd().ToString() + ": Ribbon end" + "\r\n";
                msg += printer.GetBatchProcessing().ToString() + ": Batch processing" + "\r\n";
                msg += printer.GetPrinting().ToString() + ": Printing" + "\r\n";
                msg += printer.GetPause().ToString() + ": Pause" + "\r\n";
                msg += printer.GetWaitingForPeeling().ToString() + ": Waiting for peeling" + "\r\n";
                statusBox.Text = msg;
            }
            else
            {
                timer1.Enabled = false;
                startBtn.Enabled = true;
                stopBtn.Enabled = false;

                printer.Disconnect();
                
                MessageBox.Show("PrinterCheck Error : " + ret.ToString());
            }
        }
    }
}